/*  rpc -- A console-based reverse polish notation calculator
    Copyright (C) 2000, 2001, 2002 Paul Pelzl

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/



/*  Complex.h
 *  Class declaration for complex numbers.  This is basically a
 *  wrapper for the complex arithmetic in the C math library
 *  'CCMATH'.
 */

#ifndef COMPLEX_H
#define COMPLEX_H 1

#include <cmath>

extern "C"
{
#include "ccm-compat.h"
}

class Complex
{
    public:
        Cpx cpxdata;
        
        Complex();        // Default, complex zero
        ~Complex();
        
        Complex( double, double );        // Initialize specific complex number
        Complex( bool, int, double, double);   // Initialize specific complex number
                                               //     allowing for polar format
        Complex( Cpx );                   // Initialize specific complex number
        Complex( double );                // Initialize specific real number
        
        Complex( const Complex & );       // Copy constructor
        
        Complex& operator =( const Complex& );        // Assignment

        double Real( void ) const;        // Real part
        double Imag( void ) const;        // Imaginary part
        
        double Abs( void ) const;         // Magnitude
        double Arg( void ) const;         // Phase

        Complex operator +( const Complex& );   // Addition
        Complex operator -( const Complex& );   // Subtraction
        Complex operator *( const Complex& );   // Multiplication
        Complex operator /( const Complex& );   // Division
        Complex operator -( void );             // change sign
        
        Complex operator +( const double& );    // Addition to double
        Complex operator -( const double& );    // Subtract a double
        Complex operator *( const double& );    // Multiplication by double
        Complex operator /( const double& );    // Division by double
        
        Complex Pow( const double& );           // Complex power function
        Complex Pow( const Complex& );          // Raise a complex to a complex
        
        Complex Sqrt( void );         // Complex square root
        Complex Sq( void );           // Complex square

        Complex Exp( void );          // Complex exponential
        Complex Log( void );          // Complex logarithm
        
        Complex Ten_x( void );        // Ten raised to the complex power x
        Complex Log10( void );        // Complex common logarithm
        
        Complex Sin( void );          // Complex sine
        Complex Cos( void );          // Complex cosine
        Complex Tan( void );          // Complex tangent
        
        Complex aSin( void );         // Complex inverse sin
        Complex aCos( void );         // Complex inverse cosine
        Complex aTan( void );         // Complex inverse tangent
        
        Complex Sinh( void );         // Complex hyperbolic sine
        Complex Cosh( void );         // Complex hyperbolic cosine
        Complex Tanh( void );         // Complex hyperbolic tangent
        
        Complex aSinh( void );        // Complex inverse hyperbolic sine
        Complex aCosh( void );        // Complex inverse hyperbolic cosine
        Complex aTanh( void );        // Complex inverse hyperbolic tangent
        
        Complex Inv( void );          // Complex inverse      
};        


#endif /* COMPLEX_H */

// arch-tag: wrapper for ccmath complex math (header)
