/*  rpc -- A console-based reverse polish notation calculator
    Copyright (C) 2000, 2001, 2002 Paul Pelzl

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/


/*  ComplexMatrix.h
 *  Class declaration for complex matrices.  This is basically a
 *  wrapper for the Complex matrix arithmetic in the C math library
 *  'CCMATH'.
 */
 
#ifndef COMPLEXMATRIX_H
#define COMPLEXMATRIX_H 1

#include <cmath>
#include "Complex.h"
#include "RealMatrix.h"

extern "C"
{
#include "ccm-compat.h"
}

class ComplexMatrix
{
   public:
      Cpx* mtrxdata;        // Matrix elements
      int m;                // Number of rows
      int n;                // Number of cols
      bool singular;        // Is it singular?
   
      ComplexMatrix();     // Default, 1x1 zero matrix.
      ~ComplexMatrix();
      
      ComplexMatrix( Complex*, int, int );    // Initialize mxn matrix
      ComplexMatrix( Cpx*, int, int );        // Initialize mxn matrix
      ComplexMatrix( double*, int, int );     // Initialize mxn matrix from a real matrix
      ComplexMatrix( RealMatrix );            // Initialize a complex matrix from a real matrix
      ComplexMatrix( int, int );              // Initialize mxn zero matrix
      
      ComplexMatrix( const ComplexMatrix& );    // Copy constructor
      
      ComplexMatrix& operator =( const ComplexMatrix& );    // Assignment operator
      
      
      ComplexMatrix operator +( const ComplexMatrix& );     // Addition
      ComplexMatrix operator -( const ComplexMatrix& );     // Subtraction
      ComplexMatrix operator *( const ComplexMatrix& );     // Multiplication
     
      ComplexMatrix operator *( const Complex& );     // Scalar multiplication
      ComplexMatrix operator /( const Complex& );     // Scalar division
      
      ComplexMatrix operator +( const RealMatrix& );        // Addition
      ComplexMatrix operator -( const RealMatrix& );        // Subtraction
      ComplexMatrix operator *( const RealMatrix& );        // Multiplication
      
      ComplexMatrix operator *( const double& );      // Scalar multiplication
      ComplexMatrix operator /( const double& );      // Scalar division
      
      ComplexMatrix operator -( void );                  // Negation
      
      ComplexMatrix Inv( void );       // Matrix inversion
      ComplexMatrix Trans( void );     // Transpose matrix
      
};


#endif  /* ComplexMATRIX_H */   
      

// arch-tag: wrapper for ccmath complex matrices (header)
