/*  rpc -- A console-based reverse polish notation calculator
    Copyright (C) 2000, 2001, 2002 Paul Pelzl

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/



#include "IntegerConst.h"
#include <iostream>

using namespace std;


// Default constructor
IntegerConst::IntegerConst()
{
    longdata = 0UL;
    overflow = false;
}


// Default destructor
IntegerConst::~IntegerConst()
{
}


// Copy constructor
IntegerConst::IntegerConst( const IntegerConst& oldIntegerConst )
{
    longdata = oldIntegerConst.longdata;
    overflow = oldIntegerConst.overflow;
}


// Initialize specific integer constant
IntegerConst::IntegerConst( unsigned long input )
{
    longdata = input;
    overflow = false;
}



// Initialize specific integer constant
IntegerConst::IntegerConst( double input )
{
    if( input > 0.0 )
    {
        longdata = (unsigned long)input;
    }
    else
    {
        longdata = 0UL;      
    }
    
    overflow = false;
}



// Assignment operator
IntegerConst& IntegerConst::operator =( const IntegerConst& rhs )
{
    if( this != &rhs )
    {
        longdata = rhs.longdata;
        overflow = rhs.overflow;
    }

    return( *this );
}



// Addition operator
IntegerConst IntegerConst::operator +( const IntegerConst& rhs )
{
    IntegerConst result;
    if( ULONG_MAX - longdata >= rhs.longdata )
    {       
        result = IntegerConst( longdata + rhs.longdata );
    }
    else
    {
        result.overflow = true;
    }
    return( result );
}


// Subtraction operator
IntegerConst IntegerConst::operator -( const IntegerConst& rhs )
{
    IntegerConst result( longdata - rhs.longdata );
    return( result );
}


// Multiplication operator
IntegerConst IntegerConst::operator *( const IntegerConst& rhs )
{
    IntegerConst result;
    if( longdata > 0UL )
    {
        if( ULONG_MAX / longdata > rhs.longdata )
        {
            result = IntegerConst( longdata * rhs.longdata );
        }
        else
        {
            result.overflow = true;
        }
    }
    else
    {
        result = IntegerConst( 0UL );
    }
    return( result );
}


// Division operator
IntegerConst IntegerConst::operator /( const IntegerConst& rhs )
{
    IntegerConst result;
    if( rhs.longdata != 0UL )
    {
        result = IntegerConst( longdata / rhs.longdata );
    }
    else
    {
        result.overflow = true;
    }

    return( result );
}


// Mod operator
IntegerConst IntegerConst::operator %( const IntegerConst& rhs )
{
    IntegerConst result;
    result = IntegerConst( longdata % rhs.longdata );
    return( result );
} 


// Addition to double
IntegerConst IntegerConst::operator +( const double& rhs )
{
    IntegerConst result;
    if( rhs > 0.0 )
    {
        if( ULONG_MAX - longdata >= (unsigned long) rhs )
        {
            result = IntegerConst( longdata + (unsigned long)rhs );
        }
        else
        {
            result.overflow = true;
        }
    }
    else
    {
        result = IntegerConst( longdata );
    }
    
    return( result );
}


// Subtraction by double
IntegerConst IntegerConst::operator -( const double& rhs )
{
    IntegerConst result;
    if( rhs > 0.0 && rhs <= double(longdata) )
    {
        result = IntegerConst( longdata - (unsigned long)rhs );
    }
    else
    {
        result = IntegerConst( longdata );
    }
    
    return( result );
}


// Multiplication by double
IntegerConst IntegerConst::operator *( const double& rhs )
{
    IntegerConst result;
    if( rhs >= 0.0)
    {
        if( longdata > 0UL )
        {
            if( ULONG_MAX / longdata > (unsigned long)rhs )
            {
                result = IntegerConst( longdata * (unsigned long)rhs );
            }
            else
            {
                result.overflow = true;
            }
        }
        else
        {
            result = IntegerConst( 0UL );
        }
    }
    else
    {
        result = IntegerConst( longdata );
    }
    
    return( result );
}


// Division by double
IntegerConst IntegerConst::operator /( const double& rhs )
{
    IntegerConst result;
    if( rhs > 0.0 )
    {
        result = IntegerConst( longdata / (unsigned long)rhs );
    }
    else if( rhs == 0.0 )
    {
        result.overflow = true;
    }
    else
    {
        result = IntegerConst( longdata );
    }

    return( result );
}





// arch-tag: integer constant math
