/*  rpc -- A console-based reverse polish notation calculator
    Copyright (C) 2000, 2001, 2002 Paul Pelzl

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/



/*  IntegerConst.h
 *  Class declaration for integer constants.  These will be handled a bit
 *  more carefully than type double.
 */

#ifndef INTEGERCONST_H
#define INTEGERCONST_H 1

#include <climits>

class IntegerConst
{
    public:
        unsigned long longdata;
        bool overflow;
        
        IntegerConst();        // Default, zero constant
        ~IntegerConst();
        
        IntegerConst( unsigned long );    // Initialize specific constant
        IntegerConst( const IntegerConst& );  // Initialize specific constant
        IntegerConst( double );           // Initialize specific constant        
        
        IntegerConst& operator =( const IntegerConst& );        // Assignment

        IntegerConst operator +( const IntegerConst& );   // Addition
        IntegerConst operator -( const IntegerConst& );   // Subtraction
        IntegerConst operator *( const IntegerConst& );   // Multiplication
        IntegerConst operator /( const IntegerConst& );   // Division
        IntegerConst operator %( const IntegerConst& );   // Mod
        
        IntegerConst operator +( const double& );    // Addition to double
        IntegerConst operator -( const double& );    // Subtract a double
        IntegerConst operator *( const double& );    // Multiplication by double
        IntegerConst operator /( const double& );    // Division by double       

};        


#endif /* INTEGERCONST_H */


// arch-tag: integer constant math (header)
