/*  rpc -- A console-based reverse polish notation calculator
    Copyright (C) 2000, 2001, 2002 Paul Pelzl

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/


/*  RealMatrix.h
 *  Class declaration for real matrices.  This is basically a
 *  wrapper for the real matrix arithmetic in the C math library
 *  'CCMATH'.
 */
 
#ifndef REALMATRIX_H
#define REALMATRIX_H 1

#include <cmath>
#include "Complex.h"

class ComplexMatrix;        // Forward declaration

extern "C"
{
#include "ccm-compat.h"
}

class ComplexMatrix;

class RealMatrix
{
   public:
      double* mtrxdata;     // Matrix elements
      int m;                // Number of rows
      int n;                // Number of cols
      bool singular;        // Is it singular?
   
      RealMatrix();     // Default, 1x1 zero matrix.
      ~RealMatrix();
      
      RealMatrix( double*, int, int );    // Initialize mxn matrix
      RealMatrix( int, int );             // Initialize mxn zero matrix
      
      RealMatrix( const RealMatrix& );    // Copy constructor
      
      RealMatrix& operator =( const RealMatrix& );    // Assignment operator
      
      
      RealMatrix operator +( const RealMatrix& );     // Addition
      RealMatrix operator -( const RealMatrix& );     // Subtraction
      RealMatrix operator *( const RealMatrix& );     // Multiplication
     
      RealMatrix operator *( const double& );         // Scalar multiplication
      RealMatrix operator /( const double& );         // Scalar division
      
      // The following are pointers to allow forward declaration...
      ComplexMatrix* operator +( const ComplexMatrix& ); // Addition
      ComplexMatrix* operator -( const ComplexMatrix& ); // Subtraction
      ComplexMatrix* operator *( const ComplexMatrix& ); // Multiplication
      
      ComplexMatrix* operator *( const Complex& );     // Scalar multiplication
      ComplexMatrix* operator /( const Complex& );     // Scalar division
      
      RealMatrix operator -( void );                  // Negation
      
      RealMatrix Inv( void );       // Matrix inversion
      RealMatrix Trans( void );     // Transpose matrix
      
};


#endif  /* REALMATRIX_H */   
      

// arch-tag: wrapper for ccmath real matrices (header)
