/*  rpc -- A console-based reverse polish notation calculator
    Copyright (C) 2000, 2001, 2002 Paul Pelzl

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/



#ifndef RPCCOMPLEX_H
#define RPCCOMPLEX_H

#include "RpcObject.h"
#include "Complex.h"
#include "RpcDouble.h"
#include "RpcError.h"

class RpcComplex : public RpcObject
{
    protected:
        Complex data;

    public:
        
        RpcComplex();        // Initialize a zero complex
        ~RpcComplex();       // Destroy the complex
        
        RpcComplex( const RpcComplex & );     // copy constructor
        RpcComplex& operator =( const RpcComplex& ); // assignment
        
        RpcComplex( Complex );          // Initialize specific value
        RpcComplex( Cpx );              // Initialize specific value
        RpcComplex( double );           // Initialize specific real value
        
        char* getDisplayString( RpcCalcFlags ) const;
        char* getFullscreenString( RpcCalcFlags ) const;
        
        RpcObject* operator +( const RpcObject* );
        RpcObject* operator -( const RpcObject* );
        RpcObject* operator *( const RpcObject* );
        RpcObject* operator /( const RpcObject* );
        
        RpcObject* operator -( void );
        
        RpcObject* Pow( const RpcObject* );
        
        RpcObject* Sqrt( void );
        RpcObject* Sq( void );
        
        RpcObject* Exp( void );
        RpcObject* Log( void );
        
        RpcObject* Ten_x( void );
        RpcObject* Log10( void );
        
        RpcObject* Sin( int );
        RpcObject* Cos( int );
        RpcObject* Tan( int );
        
        RpcObject* aSin( int );
        RpcObject* aCos( int );
        RpcObject* aTan( int );
        
        RpcObject* Sinh( void );
        RpcObject* Cosh( void );
        RpcObject* Tanh( void );
        
        RpcObject* aSinh( void );
        RpcObject* aCosh( void );
        RpcObject* aTanh( void );
        
        RpcObject* Real( void );
        RpcObject* Imag( void );
        
        RpcObject* Inv( void );

        RpcObject* Abs( void );
        RpcObject* Arg( int );
                
        Complex getData( void );        // Return the data.
};


#endif /* RPCCOMPLEX_H */


// arch-tag: rpc complex data type (header)
