/*  rpc -- A console-based reverse polish notation calculator
    Copyright (C) 2000, 2001, 2002 Paul Pelzl

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef RPCCOMPLEXMATRIX_H 
#define RPCCOMPLEXMATRIX_H 1

#include "RpcObject.h"
#include "ComplexMatrix.h"
#include "RpcDouble.h"
#include "RpcComplex.h"
#include "RpcRealMatrix.h"
#include "RpcError.h"

class RpcComplexMatrix : public RpcObject
{
   protected:
      ComplexMatrix data;
   
   public:
      
      RpcComplexMatrix();     // Initialize a 1x1 zero matrix
      ~RpcComplexMatrix();    // Destroy a real matrix
      
      RpcComplexMatrix( const RpcComplexMatrix& );    // Copy constructor
      RpcComplexMatrix& operator =( const RpcComplexMatrix& );
      
      RpcComplexMatrix( ComplexMatrix );     // Initialize a specific matrix
      RpcComplexMatrix( Complex*, int, int ); // Initialize a specific matrix
      
      char* getDisplayString( RpcCalcFlags ) const;  // Generate a display string
      char* getFullscreenString( RpcCalcFlags ) const;  // Generate a fullscreen display string
      
      RpcObject* operator +( const RpcObject* );
      RpcObject* operator -( const RpcObject* );
      RpcObject* operator *( const RpcObject* );
      RpcObject* operator /( const RpcObject* );
      
      RpcObject* operator -( void );
      
      RpcObject* Inv( void );
      
      RpcObject* Trans( void );
      
      ComplexMatrix getData( void );      // Return the data
};


#endif  /* RPCComplexMatrix_H */   
      
   
   
// arch-tag: rpc complex matrix data type (header)
