/*  rpc -- A console-based reverse polish notation calculator
    Copyright (C) 2000, 2001, 2002 Paul Pelzl

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/



/*  RpcDouble.h
 *  Class declaration for the rpc double precision number data type.
 *  Derived from RpcObject.
 */

#ifndef RPCDOUBLE_H
#define RPCDOUBLE_H 1

#include "RpcObject.h"
#include <cmath>

class RpcDouble : public RpcObject
{
    protected:
        double data;

    public:
        
        RpcDouble();          // Default: a zero-valued RpcDouble
        ~RpcDouble();
                
        RpcDouble( const RpcDouble& );
        RpcDouble& operator =( const RpcDouble& );
        
        RpcDouble( double );  // Initialize specific value.        

        char* getDisplayString( RpcCalcFlags ) const;
        char* getFullscreenString( RpcCalcFlags ) const;
        
        RpcObject* operator +( const RpcObject* );
        RpcObject* operator -( const RpcObject* );
        RpcObject* operator *( const RpcObject* );
        RpcObject* operator /( const RpcObject* );
        
        RpcObject* operator -( void );
        
        RpcObject* Pow( const RpcObject* );
        
        RpcObject* Sqrt( void );
        RpcObject* Sq( void );
        
        RpcObject* Exp( void );
        RpcObject* Log( void );

        RpcObject* Ten_x( void );
        RpcObject* Log10( void );
        
        RpcObject* Sin( int );
        RpcObject* Cos( int );
        RpcObject* Tan( int );
        
        RpcObject* aSin( int );
        RpcObject* aCos( int );
        RpcObject* aTan( int );
        
        RpcObject* Sinh( void );
        RpcObject* Cosh( void );
        RpcObject* Tanh( void );
        
        RpcObject* aSinh( void );
        RpcObject* aCosh( void );
        RpcObject* aTanh( void );
        
        RpcObject* Gamma( void );
        RpcObject* LogGamma( void );
        RpcObject* Factorial( void );
        
        RpcObject* Erf( void );
        RpcObject* Erfc( void );
        
        RpcObject* Floor( void );
        RpcObject* Ceil( void );
        RpcObject* NearInt( void );
        
        RpcObject* Real( void );
        RpcObject* Imag( void );
        
        RpcObject* Inv( void );

        RpcObject* Abs( void );
                
        RpcObject* ToConst( void );
        
        double getData( void );
};


#endif /* RPCDOUBLE_H */


// arch-tag: rpc double precision real data type (header)
