/*  rpc -- A console-based reverse polish notation calculator
    Copyright (C) 2000, 2001, 2002 Paul Pelzl

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/



/*  RpcIntegerConst.h
 *  Class declaration for the rpc integer constant data type.
 *  Derived from RpcObject.  This class is used primarily to handle
 *  base conversions.
 */

#ifndef RPCINTEGERCONST_H
#define RPCINTEGERCONST_H 1

#include "IntegerConst.h"
#include "RpcObject.h"
#include "RpcDouble.h"
#include "RpcError.h"
#include <cmath>

class RpcIntegerConst : public RpcObject
{
    protected:
        IntegerConst data;

    public:
        
        RpcIntegerConst();          // Default: a zero-valued constant
        ~RpcIntegerConst();
                
        RpcIntegerConst( const RpcIntegerConst& );
        RpcIntegerConst& operator =( const RpcIntegerConst& );
        
        RpcIntegerConst( IntegerConst );    // Initialize specific value.
        RpcIntegerConst( double );  // Initialize specific value.        

        char* getDisplayString( RpcCalcFlags ) const;
        char* getFullscreenString( RpcCalcFlags ) const;
        
        RpcObject* operator +( const RpcObject* );
        RpcObject* operator -( const RpcObject* );
        RpcObject* operator *( const RpcObject* );
        RpcObject* operator /( const RpcObject* );
        
        RpcObject* Mod( const RpcObject* );
        RpcObject* Real( void );        
                
        IntegerConst getData( void );
        
        void toBinary( char* ) const;
};


#endif /* RPCINTEGERCONST_H */



// arch-tag: rpc integer constant data type (header)
