/*  rpc -- A console-based reverse polish notation calculator
    Copyright (C) 2000, 2001, 2002 Paul Pelzl

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/



/*  RpcStack.h
 *  Class declaration for a stack that contains RpcObjects.
 */

#ifndef RPCSTACK_H
#define RPCSTACK_H 1

#include <cstdlib>
#include "RpcDouble.h"
#include "RpcComplex.h"
#include "RpcRealMatrix.h"
#include "RpcComplexMatrix.h"
#include "RpcIntegerConst.h"
#include "RpcError.h"

#include <fstream>
#include <iostream>

using namespace std;


// #define VERSION "0.95" comes from automake/autoconf via -D now


const int DEFAULT_STACK_SIZE = 99;
const int STACK_SIZE_ADDON = 100;        // Grow by 100 elements at a time


class RpcStack
{
    private:
        int count;                  // Number of elements
        int actualSize;             // Amount of storage allocated
        
        RpcObject** element;        // Array of RpcObjects
        RpcObject* stackError;      // Stores a generic error object
        
    public:
        RpcStack();                 // Create empty stack
        ~RpcStack();                // Destructor
            
        RpcStack( const RpcStack& );                // Copy constructor
        RpcStack& operator =( const RpcStack& );    // Assignment
        
        void push( const RpcObject* );         // Push an element on the stack
        RpcObject* pop( void );                // Pop an element off the stack
        void clearAll( void );                 // Clear all stack elements.
        void drop( int );                      // Drop a specific stack element.
        void keepn( int );                     // Keep only the top n elements.
        void rollUp( int );                    // Cyclically roll elements to top of stack.
        void rollDown( int );                  // Cyclically roll elements toward bottom of stack.        
        int numElements( void ) const;         // Return number of elements
        
        char* getDisplayString( int, RpcCalcFlags ) const;   // Get the display string from the object
                                               // at a specified level
        char* getFullscreenString( int, RpcCalcFlags ) const;   // Get the fullscreen display string
                                                  // from the object at a specified level
        
        unsigned int getTopType( void );       // Return the data type of top element
        RpcObject* const viewElement( int ) const;   // Look at a specific element

        void save( ofstream& ) const;           // Save stack to a file.
        void load( ifstream& );                 // Load stack from a file.
};

#endif  /*  RPCSTACK_H  */


// arch-tag: rpc data stack (header)
