
/*  rpc -- A console-based reverse polish notation calculator
    Copyright (C) 2000, 2001, 2002 Paul Pelzl

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/


/*  ccm-compat.c
 *  A C wrapper function that allows CCMATH to be called without
 *  conflictions with C++ functions (particulary clog).
 *  Should be compiled as a C object, not a C++ object.
 */
 

#include <ccmath.h>
#include <stdio.h>

inline Cpx cMul( Cpx s, Cpx t )
{
    return( cmul(s, t) );
}


inline Cpx cDiv( Cpx s, Cpx t )
{
    return( cdiv(s, t) );
}


inline Cpx cAdd( Cpx s, Cpx t )
{
    return( cadd(s, t) );
}


inline Cpx cSub( Cpx s, Cpx t )
{
    return( csub(s, t) );
}


inline Cpx cRmu( double a, Cpx z )
{
    return( crmu(a, z) );
}


inline Cpx cImu( double b, Cpx z )
{
    return( cimu(b, z) );
}


inline Cpx cCng( Cpx z )
{
    return( ccng(z) );
}


inline Cpx cDef( double r, double i )
{
    return( cdef(r, i) );
}


inline double cAbs( Cpx c )
{
    return( cabs(c) );
}


inline double cNrm( Cpx z )
{
    return( cnrm(z) );
}


inline Cpx cExp( Cpx z )
{
    return( cexp(z) );
}


inline Cpx cLog( Cpx z )
{
    return( clog(z) );
}


inline Cpx cSinh( Cpx z )
{
    return( csinh(z) );
}


inline Cpx cCosh( Cpx z )
{
    return( ccosh(z) );
}


inline Cpx cTanh( Cpx z )
{
    return( ctanh(z) );
}


inline Cpx cAsinh( Cpx z )
{
    return( casinh(z) );
}


inline Cpx cAcosh( Cpx z )
{
    return( cacosh(z) );
}


inline Cpx cAtanh( Cpx z )
{
    return( catanh(z) );
}


inline Cpx cAsin( Cpx z )
{
    return( casin(z) );
}


inline Cpx cAcos( Cpx z )
{
    return( cacos(z) );
}


inline Cpx cAtan( Cpx z )
{
    return( catan(z) );
}


inline Cpx cSqrt( Cpx z )
{
    return( csqrt(z) );
}


inline Cpx cSin( Cpx z )
{
    return( csin(z) );
}


inline Cpx cCos( Cpx z )
{
    return( ccos(z) );
}


inline Cpx cTan( Cpx z )
{
    return( ctan(z) );
}


/*  -------------    Matrix routines --------------- */

inline void Rmmult( double* mat, double* a, double* b, int m, int k, int n)
{
   rmmult( mat, a, b, m, k, n );
}


inline void Cmmult( Cpx* mat, Cpx* a, Cpx* b, int m, int k, int n )
{
   cmmult( mat, a, b, m, k, n );
}


inline int Minv( double a[], int n )
{
   return( minv(a, n) );
}


inline int cMinv( Cpx a[], int n )
{
   return( cminv(a, n) );
}


inline void Mattr( double* a, double* b, int m, int n )
{
   mattr( a, b, m, n );
}


inline void cMattr( Cpx* a, Cpx* b, int m, int n )
{
   cmattr( a, b, m, n );
}




// arch-tag: ccmath C++ compatibility wrapper
